#!/usr/bin/env python
# pylint: skip-file
from mi_graph.util import cli

cli()
